@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "gtasks" "0.2.2"
+(define-package "gtasks" "20251028.336"
   "Google Tasks API (sync)."
   '((emacs "27.1"))
   :url "https://github.com/thndrbrrr/gtasks"
-  :commit "1b5aba8ee152d9646fd6062f45824cb5fa4b127b"
-  :revdesc "1b5aba8ee152"
+  :commit "574205a511b5788e3711f86a438573a62a08c472"
+  :revdesc "574205a511b5"
   :keywords '("convenience" "tools" "google" "tasks" "api")
   :authors '((nil . "thndrbrrr@gmail.com"))
   :maintainers '((nil . "thndrbrrr@gmail.com")))
